@@ -7,17 +7,9 @@ from verstack.tools import timer
 
 class FeatureSelector:  
 
-    __version__ = '0.0.4'
+    __version__ = '0.0.9'
 
     def __init__(self, **kwargs):
-                 # objective = 'regression', 
-                 # auto = False,
-                 # allowed_score_gap = 0.0,
-                 # final_scoring_model = None,
-                 # default_model_linear = False,
-                 # custom_model = None, 
-                 # subset_size_mb = 20,
-                 # verbose = True):
 
         '''
         Initialize FeatureSelectorRFE instance.
@@ -54,7 +46,8 @@ class FeatureSelector:
             Verbose flag for short informative messages. The default is True.
             fit_transform has it's own 'verbosity' setting which controlls the 
             verbosity of sklearn.feature_selection.RFECV.
-
+        random_state : int, optional
+            Random state for reproducibility. The default is None.
         Returns
         -------
         None.
@@ -68,6 +61,7 @@ class FeatureSelector:
         self.custom_model = kwargs.get('custom_model', None)
         self.subset_size_mb = kwargs.get('subset_size_mb', 20)
         self.verbose = kwargs.get('verbose', True)
+        self.random_state = kwargs.get('random_state', None)
         self._model = self._initialise_model(self.custom_model, self.default_model_linear)
         self.selected_features = None
         self._score_diff_percent = None # placeholder for print results in the console 
@@ -79,6 +73,7 @@ class FeatureSelector:
             \n                   auto: {self.auto}\
             \n                   allowed_score_gap: {self.allowed_score_gap}\
             \n                   subset_size_mb: {self.subset_size_mb}\
+            \n                   random_state: {self.random_state}\
             \n                   verbose: {self.verbose})'
         
     # Validate init arguments
@@ -156,6 +151,19 @@ class FeatureSelector:
         else:
             self._verbose = value
     # -------------------------------------------------------------------------
+    # verbose
+    @property
+    def random_state(self):
+        return self._random_state
+    
+    @random_state.setter
+    def random_state(self, value):
+        if not self._is_int(value) and value is not None:
+            print(f'{value} is not a valid random_state argument, must be an int or None. Setting default random_state to None')
+            self._random_state = None
+        else:
+            self._random_state = value
+    # -------------------------------------------------------------------------
     # auto
     @property
     def auto(self):
@@ -225,7 +233,7 @@ class FeatureSelector:
             selected train features.
 
         '''
-        self._validate_pandas(X, y)
+        self._validate_pandas(X)
         self.printer.print('Initiating FeatureSelector', order=1)
         if self.auto:
             self.printer.print(f'Comparing LinearRegression and RandomForest for feature selection', order = 2)
@@ -238,12 +246,9 @@ class FeatureSelector:
         self.printer.print(f'Selected {len(self.selected_features)} features from {X.shape[1]}', order=3)
         return X[self.selected_features]
 
-    def _validate_pandas(self, X, y=None):
+    def _validate_pandas(self, X):
         if not isinstance(X, pd.DataFrame):
             raise TypeError('Invalid argument for X, must be a pandas.DataFrame')
-        if y is not None:
-            if not isinstance(y, pd.Series):
-                raise TypeError('Invalid argument y, must be a pandas.Series')
 
     def _prepare_data_apply_selector(self, X, y, selector, scale_data = False):
         X_subset, y_subset = self._subset_data(X, y)
@@ -329,13 +334,17 @@ class FeatureSelector:
         '''Set up the default LGBM (regressor or classifier) or use the user defined model'''
         if self.final_scoring_model is None:
             from lightgbm import LGBMClassifier, LGBMRegressor
+            verbosity = -1
             if self.objective == 'regression':
-                model = LGBMRegressor()
+                model = LGBMRegressor(verbosity=verbosity, n_jobs = -1, 
+                                      random_state = self.random_state)
             else:
-                if y.nunique() == 2:
-                    model = LGBMClassifier(objective = 'binary')
+                if len(np.unique(y)) == 2:
+                    model = LGBMClassifier(objective = 'binary', verbosity=verbosity, 
+                                           n_jobs = -1, random_state = self.random_state)
                 else:
-                    model = LGBMClassifier(objective = 'multiclass')                
+                    model = LGBMClassifier(objective = 'multiclass', verbosity=verbosity, 
+                                           n_jobs = -1, random_state = self.random_state)
         else:
             model = self.final_scoring_model
         return model
@@ -459,30 +468,31 @@ class FeatureSelector:
         '''Return Ridge() or LogisticRegression() from sklearn'''
         if self.objective == 'regression':
             from sklearn.linear_model import Ridge
-            return Ridge()
+            return Ridge(random_state = self.random_state)
         else:
             from sklearn.linear_model import LogisticRegression
-            return LogisticRegression(max_iter=1000)
+            return LogisticRegression(max_iter=1000, random_state = self.random_state)
         
     def _get_randomforest_model(self):
         '''Return RFClassifier or RFRegressor from sklearn'''
         if self.objective == 'regression':
             from sklearn.ensemble import RandomForestRegressor
-            return RandomForestRegressor(n_estimators=50, max_depth=2)
+            return RandomForestRegressor(n_estimators=50, max_depth=2, n_jobs=-1, 
+                                         random_state = self.random_state)
         else:
             from sklearn.ensemble import RandomForestClassifier
-            return RandomForestClassifier(n_estimators=50, max_depth=2)           
+            return RandomForestClassifier(n_estimators=50, max_depth=2, n_jobs=-1, 
+                                          random_state = self.random_state)
         
     def _subset_data(self, X, y):
         '''Subset train dataset by n megabytes.
         Used to speed up experiments during feature engineering & model tuning.'''
-        temp = pd.concat([X, y], axis=1)
+        temp = pd.concat([X, pd.Series(y, name='target')], axis=1)
         data_size = np.round(temp.memory_usage().sum()/(1024*1024), 2)
     
         if data_size > self.subset_size_mb:
             batch = self.subset_size_mb / data_size
             experimental_data = temp.sample(frac=batch)
-            experimental_data.reset_index(drop=True, inplace=True)
             X = experimental_data.drop('target', axis=1)
             y = experimental_data.target
             self.printer.print(f'Data decreased for experiments. Working with {np.round(batch*100,2)}% of data', order = 3)
@@ -490,6 +500,8 @@ class FeatureSelector:
         else:
             self.printer.print('Experiments are carried out on complete dataset', order = 3)
         del temp, data_size
+        X.reset_index(drop=True, inplace=True)
+        y.reset_index(drop=True, inplace=True)
         return X, y  
 
     def _scale_data(self, X):
@@ -502,8 +514,11 @@ class FeatureSelector:
     def _transform_data_to_float_32(self, X_subset, y_subset):
         '''Transform to float32, drop rows with np.nan, np.inf'''
         X_subset = pd.DataFrame(X_subset).astype('float32')
-        X_subset = X_subset[~X_subset.isin([np.nan, np.inf, -np.inf]).any(1)]
-        y_subset = y_subset.loc[X_subset.index]
+        # Replace infinite updated data with nan
+        X_subset.replace([np.inf, -np.inf], np.nan, inplace=True)
+        # Drop rows with NaN
+        X_subset.dropna(inplace=True)       
+        y_subset = pd.Series(y_subset).loc[X_subset.index]
         return X_subset, y_subset
 
     def _get_sklearn_scoring_func_name(self, y):
@@ -511,7 +526,7 @@ class FeatureSelector:
         if self.objective == 'regression':
             return 'neg_root_mean_squared_error'
         else:
-            if y.nunique() == 2:
+            if len(np.unique(y)) == 2:
                 return 'roc_auc'
             else:
                 return 'neg_log_loss'
