@@ -6,7 +6,6 @@ from verstack.categoric_encoders.FrequencyEncoder import FrequencyEncoder
 from verstack.categoric_encoders.WeightOfEvidenceEncoder import WeightOfEvidenceEncoder
 # standalone classes
 from verstack.NaNImputer import NaNImputer
-from verstack.NaNImputerLegacy import NaNImputerLegacy
 from verstack.Multicore import Multicore
 from verstack.ThreshTuner import ThreshTuner
 from verstack.DateParser import DateParser
@@ -14,7 +13,7 @@ from verstack.FeatureSelector import FeatureSelector
 from verstack.PandasOptimizer import PandasOptimizer
 # LGBMTuner import
 from verstack.lgbm_optuna_tuning.LGBMTuner import LGBMTuner
-# Stacker import
-from verstack.stacking.Stacker import Stacker
+# Depreciated imports
+from verstack.stacking_depreciated.Stacker import Stacker
 #create a __version__ attribute in the verstack class
 from .version import __version__
