@@ -8,7 +8,9 @@ Created on Fri Mar 11 20:34:45 2022
 
 import numpy as np
 from sklearn.metrics import mean_absolute_error as mae
+from sklearn.metrics import root_mean_squared_error as rmse
 from sklearn.metrics import mean_squared_error as mse
+from sklearn.metrics import root_mean_squared_log_error as rmsle
 from sklearn.metrics import mean_squared_log_error as msle
 from sklearn.metrics import r2_score as r2
 from sklearn.metrics import roc_auc_score as auc
@@ -86,17 +88,24 @@ def _percentage_error(real, pred):
 # mae imported from sklearn
 # ------------------------------------------------------------------------------
 
-def rmse(real, pred):
-    return mse(real, pred, squared = False)
+# rmse imported from sklearn
 # ------------------------------------------------------------------------------
 
-def rmsle(real, pred):
-    '''Changes negative predictions to 0 for correct calculation'''
-    try:
-        return msle(real, pred, squared = False)
-    except ValueError:
-        pred_non_negative, real_non_negative = remove_negatives(pred, real)
-        return msle(real_non_negative, pred_non_negative, squared = False)
+# rmsle imported from sklearn
+# ------------------------------------------------------------------------------
+
+# def rmse(real, pred):
+#     return mse(real, pred, squared = False)
+# ------------------------------------------------------------------------------
+
+# def rmsle(real, pred):
+#     '''Changes negative predictions to 0 for correct calculation'''
+#     try:
+#         return msle(real, pred, squared = False)
+#     except ValueError:
+#         pred_non_negative, real_non_negative = remove_negatives(pred, real)
+#         return msle(real_non_negative, pred_non_negative, squared = False)
+
 
 # ------------------------------------------------------------------------------
 
@@ -347,11 +356,13 @@ def print_lower_greater_better(metric):
     else:
         return 'greater-better'
 
+"""
+Depreciation note: final nrounds optimization is depreciated starting from verstack 3.8.1 in favor of early_stopping during optuna trials.
+So all below code is legacy and will be removed in future versions.
 
-
-# LGBM custom metrics for nrounds optimization only. Used in optimize_n_estimators()
-# function. 'pred' object is lgbm.Dataset - pred.label attribute is used to extract the 
-# actual predicted labels
+LGBM custom metrics for nrounds optimization only. Used in optimize_n_estimators()
+function. 'pred' object is lgbm.Dataset - pred.label attribute is used to extract the 
+actual predicted labels
 
 def get_n_rounds_optimization_metric(eval_metric):
     '''Create evaluation function in lgbm.train supported format for n_rounds optimization'''
@@ -497,18 +508,4 @@ def lgb_lift(pred, real):
     is_higher_better = True
     score = lift(real.label, pred>0.5)
     return 'lgb_lift', score, is_higher_better
-
-# ------------------------------------------------------------------------------
-'''
-def get_study_direction(metric):
-    from lgb_metrics import regression_metrics, classification_metrics
-    if metric in regression_metrics:
-            direction = 'minimize'
-    else:
-        if metric != 'log_loss':
-            direction = 'maximize'
-        else:
-            direction = 'minimize'
-    return direction
-'''
-
+"""
